@@ -40,8 +40,8 @@ static gchar *DefaultHeight = "GnomeDbErrorDlg|GtkWindow::default_height";
 static gchar *Shrink = "GnomeDbErrorDlg|GtkWindow::allow_shrink";
 static gchar *Grow = "GnomeDbErrorDlg|GtkWindow::allow_grow";
 static gchar *AutoShrink = "GnomeDbErrorDlg|GtkWindow::auto_shrink";
-static gchar *WMName = "GnomeDbErrorDlg|GtkWindow::wmclass_name";
-static gchar *WMClass = "GnomeDbErrorDlg|GtkWindow::wmclass_class";
+static gchar *IconName = "GnomeDbErrorDlg|GtkWindow::icon_name";
+static gchar *FocusOnMap = "GnomeDbErrorDlg|GtkWindow::focus_on_map";
 
 static gchar *Resizable = "GnomeDbErrorDlg|GtkWindow::resizable";
 static gchar *DestroyWithParent = "GnomeDbErrorDlg|GtkWindow::destroy_with_parent";
@@ -100,7 +100,7 @@ gb_gnome_db_errordlg_create_properties (GtkWidget * widget, GbWidgetCreateArgDat
 					Title, Type, Position, Modal,
 					DefaultWidth, DefaultHeight,
 					Shrink, Grow, AutoShrink,
-					WMName, WMClass,
+					IconName, FocusOnMap,
 					Resizable, DestroyWithParent, Icon,
 					Role, TypeHint, SkipTaskbar,
 					SkipPager, Decorated, Gravity);
@@ -119,7 +119,7 @@ gb_gnome_db_errordlg_get_properties (GtkWidget *widget, GbWidgetGetArgData * dat
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -138,7 +138,7 @@ gb_gnome_db_errordlg_set_properties (GtkWidget * widget, GbWidgetSetArgData * da
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
 				     SkipPager, Decorated, Gravity);
@@ -170,12 +170,17 @@ gb_gnome_db_errordlg_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
   if (data->create_widget)
     {
       gchar *title;
+      gboolean translatable, context;
+      gchar *comments;
+
+      glade_util_get_translation_properties (widget, Title, &translatable,
+					     &comments, &context);
+      source_add_translator_comments (data, translatable, comments);
 
       title = GTK_WINDOW (widget)->title;
       source_add (data, "  %s = gnome_db_error_dialog_new (%s);\n",
 		  data->wname,
-		  title ? source_make_string (title, data->use_gettext)
-		        : "NULL");
+		  title ? source_make_string_full (title, data->use_gettext && translatable, context) : "NULL");
     }
 
   gb_widget_write_standard_source (widget, data);
@@ -185,7 +190,7 @@ gb_gnome_db_errordlg_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
 				   NULL, Type, Position, Modal,
 				   DefaultWidth, DefaultHeight,
 				   Shrink, Grow, AutoShrink,
-				   WMName, WMClass,
+				   IconName, FocusOnMap,
 				   Resizable, DestroyWithParent, Icon,
 				   Role, TypeHint, SkipTaskbar,
 				   SkipPager, Decorated, Gravity);
