@@ -40,13 +40,20 @@ static gchar *DefaultHeight = "GnomeDbLoginDlg|GtkWindow::default_height";
 static gchar *Shrink = "GnomeDbLoginDlg|GtkWindow::allow_shrink";
 static gchar *Grow = "GnomeDbLoginDlg|GtkWindow::allow_grow";
 static gchar *AutoShrink = "GnomeDbLoginDlg|GtkWindow::auto_shrink";
-static gchar *WMName = "GnomeDbLoginDlg|GtkWindow::wmclass_name";
-static gchar *WMClass = "GnomeDbLoginDlg|GtkWindow::wmclass_class";
+static gchar *IconName = "GnomeDbLoginDlg|GtkWindow::icon_name";
+static gchar *FocusOnMap = "GnomeDbLoginDlg|GtkWindow::focus_on_map";
 
 static gchar *Resizable = "GnomeDbLoginDlg|GtkWindow::resizable";
 static gchar *DestroyWithParent = "GnomeDbLoginDlg|GtkWindow::destroy_with_parent";
 static gchar *Icon = "GnomeDbLoginDlg|GtkWindow::icon";
 
+static gchar *Role = "GnomeDbLoginDlg|GtkWindow::role";
+static gchar *TypeHint = "GnomeDbLoginDlg|GtkWindow::type_hint";
+static gchar *SkipTaskbar = "GnomeDbLoginDlg|GtkWindow::skip_taskbar_hint";
+static gchar *SkipPager = "GnomeDbLoginDlg|GtkWindow::skip_pager_hint";
+static gchar *Decorated = "GnomeDbLoginDlg|GtkWindow::decorated";
+static gchar *Gravity = "GnomeDbLoginDlg|GtkWindow::gravity";
+
 /******
  * NOTE: To use these functions you need to uncomment them AND add a pointer
  * to the function in the GbWidget struct at the end of this file.
@@ -77,6 +84,9 @@ gb_gnome_db_logindlg_new (GbWidgetNewData *data)
   gtk_signal_connect (GTK_OBJECT (widget), "delete_event",
 		      GTK_SIGNAL_FUNC (editor_close_window), NULL);
 
+  gtk_object_set_data (GTK_OBJECT (widget), TypeHint,
+		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
+
   return widget;
 }
 
@@ -92,8 +102,10 @@ gb_gnome_db_logindlg_create_properties (GtkWidget * widget, GbWidgetCreateArgDat
 					Title, Type, Position, Modal,
 					DefaultWidth, DefaultHeight,
 					Shrink, Grow, AutoShrink,
-					WMName, WMClass,
-					Resizable, DestroyWithParent, Icon);
+					IconName, FocusOnMap,
+					Resizable, DestroyWithParent, Icon,
+					Role, TypeHint, SkipTaskbar,
+					SkipPager, Decorated, Gravity);
 }
 
 
@@ -109,8 +121,10 @@ gb_gnome_db_logindlg_get_properties (GtkWidget *widget, GbWidgetGetArgData * dat
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
-				     Resizable, DestroyWithParent, Icon);
+				     IconName, FocusOnMap,
+				     Resizable, DestroyWithParent, Icon,
+				     Role, TypeHint, SkipTaskbar,
+				     SkipPager, Decorated, Gravity);
 }
 
 
@@ -126,8 +140,10 @@ gb_gnome_db_logindlg_set_properties (GtkWidget * widget, GbWidgetSetArgData * da
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
-				     Resizable, DestroyWithParent, Icon);
+				     IconName, FocusOnMap,
+				     Resizable, DestroyWithParent, Icon,
+				     Role, TypeHint, SkipTaskbar,
+				     SkipPager, Decorated, Gravity);
 }
 
 
@@ -155,12 +171,17 @@ gb_gnome_db_logindlg_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
   if (data->create_widget)
     {
       gchar *title;
+      gboolean translatable, context;
+      gchar *comments;
+
+      glade_util_get_translation_properties (widget, Title, &translatable,
+					     &comments, &context);
+      source_add_translator_comments (data, translatable, comments);
 
       title = GTK_WINDOW (widget)->title;
       source_add (data, "  %s = gnome_db_login_dialog_new (%s);\n",
 		  data->wname,
-		  title ? source_make_string (title, data->use_gettext)
-		        : "NULL");
+		  title ? source_make_string_full (title, data->use_gettext && translatable, context) : "NULL");
     }
 
   gb_widget_write_standard_source (widget, data);
@@ -170,8 +191,10 @@ gb_gnome_db_logindlg_write_source (GtkWidget * widget, GbWidgetWriteSourceData *
 				   NULL, Type, Position, Modal,
 				   DefaultWidth, DefaultHeight,
 				   Shrink, Grow, AutoShrink,
-				   WMName, WMClass,
-				   Resizable, DestroyWithParent, Icon);
+				   IconName, FocusOnMap,
+				   Resizable, DestroyWithParent, Icon,
+				   Role, TypeHint, SkipTaskbar,
+				   SkipPager, Decorated, Gravity);
 }
 
 
@@ -202,6 +225,7 @@ gb_gnome_db_logindlg_init ()
   gbwidget.gb_widget_set_properties	= gb_gnome_db_logindlg_set_properties;
   gbwidget.gb_widget_write_source	= gb_gnome_db_logindlg_write_source;
   gbwidget.gb_widget_create_popup_menu	= gb_gnome_db_logindlg_create_popup_menu;
+  gbwidget.gb_widget_destroy = gb_window_destroy;
 
   return &gbwidget;
 }
